# Generated by Django 3.2.12 on 2022-10-05 07:39

from collections import defaultdict
from datetime import datetime

from django.db import migrations


def migrate_node_metadata(apps, schema_editor):
    NodeMetadata = apps.get_model("maasserver", "NodeMetadata")
    Secret = apps.get_model("maasserver", "Secret")

    node_secrets = defaultdict(dict)
    node_metadata = NodeMetadata.objects.filter(
        key__in=("lxd_certificate", "virsh_password")
    )
    for node_id, key, value in node_metadata.values_list(
        "node_id", "key", "value"
    ):
        node_secrets[node_id][key.replace("_", "-")] = value

    now = datetime.utcnow()
    Secret.objects.bulk_create(
        [
            Secret(
                path=f"node/{node_id}/deploy-metadata",
                value=value,
                created=now,
                updated=now,
            )
            for node_id, value in node_secrets.items()
        ]
    )
    node_metadata.delete()


class Migration(migrations.Migration):

    dependencies = [
        ("maasserver", "0285_migrate_external_auth_secrets"),
    ]

    operations = [migrations.RunPython(migrate_node_metadata)]
